CohortQuery

Struct CohortQuery 

pub struct CohortQuery {
    pub artifact: Option<ArtifactRef>,
    pub discipline: Option<IdentityDiscipline>,
}
Filter passed to HistoricalSource::enumerate().

Fields

artifact: Option<ArtifactRef>

If set, restrict enumeration to artifacts matching this ref under any discipline.

discipline: Option<IdentityDiscipline>

If set, apply this identity discipline when grouping states into cohorts.

Implementations

Source

impl CohortQuery

pub fn all() -> Self

Enumerate all artifacts under all disciplines.